BlendRecipe: Combining recipes from different tables — Recipe 0.14.0 documentation

# BlendRecipe: Combining recipes from different tables

The BlendRecipe extension lets you combine data from multiple recipes.

class `recipe.` `BlendRecipe`(*args, **kwargs)

  Add blend recipes, used for joining data from another table to a base table

  Supply a second recipe with a different `from` Optionally supply join criteria, if no join criteria is provided join will be attempted using constraints. All ingredients from the blended recipe will be hoisted to the base recipe except for ingredients that are used for joins (they must be the same anyway).

  Supports blend (inner) and full_blend (outer) joins.

  `blend`(blend_recipe, join_base, join_blend)

    Blend a recipe into the base recipe. This performs an inner join of the blend_recipe to the base recipe’s SQL.

  `full_blend`(blend_recipe, join_base, join_blend)

    Blend a recipe into the base recipe preserving values from both recipes.

    This performs an outer join of the blend_recipe to the base recipe.